MAX30105 - Heart Rate, Oximeter, Smoke Sensor
=============================================

|Build Status| |Coverage Status| |PyPi Package| |Python Versions|

The MAX30105 is an precision optical sensor that can be used to measure
heart rate, pulse oximetry (SPO2 / blood oxygen saturation), and smoke
(and other particles).

Installing
==========

Stable library from PyPi:

-  Just run ``sudo pip install max30105``

Latest/development library from GitHub:

-  ``git clone https://github.com/pimoroni/max30105-python``
-  ``cd max30105-python``
-  ``sudo ./install.sh``

Important!
==========

**This code should not be used for medical diagnosis, as the basis for a
real smoke or fire detector, or in life-critical situations. It's for
fun/novelty use only, so bear that in mind while using it.**

.. |Build Status| image:: https://travis-ci.com/pimoroni/max30105-python.svg?branch=master
   :target: https://travis-ci.com/pimoroni/max30105-python
.. |Coverage Status| image:: https://coveralls.io/repos/github/pimoroni/max30105-python/badge.svg?branch=master
   :target: https://coveralls.io/github/pimoroni/max30105-python?branch=master
.. |PyPi Package| image:: https://img.shields.io/pypi/v/max30105.svg
   :target: https://pypi.python.org/pypi/max30105
.. |Python Versions| image:: https://img.shields.io/pypi/pyversions/max30105.svg
   :target: https://pypi.python.org/pypi/max30105
